@@ -21,6 +21,7 @@ class HTMLStripper(HTMLParser):
         self.reset()
         self.strict = False
         self.fed = []
+        self.convert_charrefs = True
 
     def handle_data(self, d):
         self.fed.append(d)
@@ -52,7 +53,7 @@ Content-Type: text/plain
 """
 
     def __init__(self, db='~/.f2mdb', maildir='~/mail/feeds', strip=False,
-                 silent=False):
+                 nolinks=False, silent=False):
         self.silent = silent
         self.maildir = os.path.expanduser(maildir)
         self.db = os.path.expanduser(db)
